//+------------------------------------------------------------------+
//|                                                ShadowCandles.mq4 |
//|                            Copyright  2009,  (api) |
//|                                              p231970@hotmail.com |
//+------------------------------------------------------------------+
#property copyright "Copyright  2009,  (api)"
#property link      "p231970@hotmail.com"

#property indicator_chart_window
//---- input parameters
extern int       iPeriod=720;
extern int       tShift = 60;
extern int       iNumCandles=80;
extern color     BullCandle=Maroon;
extern color     BearCandle=Blue;
extern color     BullShadow=Maroon;
extern color     BearShadow=Blue;

double data[][6];
bool ValidParams=true;

int init()
{
    if(iPeriod<=Period())
        ValidParams=false;
    if(MathMod(iPeriod,Period())!=0)
        ValidParams=false;
    if(MathMod(tShift,Period())!=0)
        ValidParams=false;
    if(MathMod(1440,iPeriod)!=0)
        ValidParams=false;
        
    ArrayResize(data,iNumCandles);
        
}

//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{
   for(int i=0;i<iNumCandles;i++)
   {
      ObjectDelete("ShadowCandle"+i);
      ObjectDelete("ShadowCandleShadow"+i);
   }
   Comment("");
   return(0);
}
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
    if(!ValidParams)
    {
        Comment("Invalid parameters!");
        return(0);
    }

    int         PerSec=iPeriod*60;
    datetime    time_0, time_F;
    static datetime last_time_0=0;
    double      dO, dC, dH, dL;
    int         iSh=0, iBar=0, i=0;

   int counted_bars=IndicatorCounted();
   if(counted_bars<0) return(-1);
   if(counted_bars>0) counted_bars--;
   int limit=Bars-counted_bars;
   if(counted_bars==0) limit-=1;
  
    while(i<iNumCandles)
    {
       if (iBar>=limit) break;
        time_0=MathFloor((1.0*Time[iBar]-tShift*60)/PerSec);
        time_0*=PerSec;
        time_0+=tShift*60;
        time_F=time_0+PerSec-Period()*60;

        iSh=iBarShift(NULL,0,time_0);
        dO=Open[iSh];
        dC=Close[iBar];
        dH=High[iHighest(NULL,0,MODE_HIGH,iSh+1-iBar,iBar)];
        dL=Low[ iLowest( NULL,0,MODE_LOW, iSh+1-iBar,iBar)];

        data[i][0]=time_0; 
        data[i][1]=dO;
        data[i][2]=dL;
        data[i][3]=dH;
        data[i][4]=dC;
        data[i][5]=time_F;

        DrawCandle(i);

        if(i==0)
            if(last_time_0<time_0)
                last_time_0=time_0;
            else
                break;
        
        iSh++;
        iBar=iSh;
        i++;
    }
    return(0);
}

void DrawCandle(int bar)
{
   string name1 = "ShadowCandleShadow"+bar;
   string name2 = "ShadowCandle"+bar;
   if(!ObjectCreate(name1,OBJ_RECTANGLE,0,data[bar][0],data[bar][2],data[bar][5],data[bar][3]))
   {
      ObjectSet(name1,OBJPROP_TIME1,data[bar][0]);
      ObjectSet(name1,OBJPROP_TIME2,data[bar][5]);
      ObjectSet(name1,OBJPROP_PRICE1,data[bar][2]);
      ObjectSet(name1,OBJPROP_PRICE2,data[bar][3]);
   }
   ObjectSet(name1,OBJPROP_BACK,false);
   if(!ObjectCreate(name2,OBJ_RECTANGLE,0,data[bar][0],data[bar][1],data[bar][5],data[bar][4]))
   {
      ObjectSet(name2,OBJPROP_TIME1,data[bar][0]);
      ObjectSet(name2,OBJPROP_TIME2,data[bar][5]);
      ObjectSet(name2,OBJPROP_PRICE1,data[bar][1]);
      ObjectSet(name2,OBJPROP_PRICE2,data[bar][4]);
   }
   ObjectSet(name2,OBJPROP_BACK,true);
   if(data[bar][1]<data[bar][4])
   {
      ObjectSet(name1,OBJPROP_COLOR, BullShadow);
      ObjectSet(name2,OBJPROP_COLOR, BullCandle);
   }else
   {
      ObjectSet(name1,OBJPROP_COLOR, BearShadow);
      ObjectSet(name2,OBJPROP_COLOR, BearCandle);
   }
}
//+------------------------------------------------------------------+